c  EQ2AZ: convert geocentric equatoreal coordinates to azimuthal
c  Miroslav Broz (miroslav.broz@email.cz), Dec 26th 2001

c-----------------------------------------------------------------------

      program EQTOAZ

      implicit none

c constants
      integer maxstr,iu
      parameter(maxstr = 16)
      parameter(iu = 20)
      real*8 pi,degrad
      parameter(pi = 3.1415926535d0, degrad = pi/180.0d0)

c  input variables
      character*80 datestr,observatory,locstr,edbfile,obsname,obsalias
      real*8 jdate,ra,de,
     :  lambda,phi,height,
     :  year,month,day,hour,minute,second,
     :  a,h

c  temporary vars
      integer i,j
      character*16 s(maxstr)
      character*255 line
      logical topocentric
      real*8 s0,ss,st

c  functions
      integer split,length
      real*8 jd,reads

c-----------------------------------------------------------------------

c
c  read input parameters
c
      read(*,10,end=999,err=999) datestr
10    format(a)
      read(*,10,end=999,err=999) observatory
      read(*,10,end=999,err=999) locstr
      read(*,10,end=999,err=999) edbfile

      j = split(datestr,' ',s,maxstr)
      if (j.eq.1) then
        read(s(1),*,end=999,err=999) jdate
      else
        call reads_split(s(1),'/',year,month,day)
        call reads_split(s(2),':',hour,minute,second)
        jdate = jd(year,month,day
     :    +hour/24.d0+minute/1440.d0+second/86400.d0)
      endif 

c-----------------------------------------------------------------------

c
c  look for the observatory location in eq2az.local
c
      if (index(observatory(1:2),'. ').eq.0) then
        topocentric = .true.
        open(unit=1,name='./min.local',status='old',form='formatted',
     :    err=30)
20      continue
          read(1,10,end=30,err=30) line
          obsname = line(1:40)
          obsalias = line(41:45)
        if (index(obsname,observatory)+index(obsalias,observatory).eq.0)
     :    goto 20
        read(line(46:),*,end=30,err=30) lambda,phi,height
        lambda = lambda * degrad
        phi = phi * degrad
        close(1)
        goto 40

30      continue
        write(*,31) observatory(1:length(observatory))
31      format('MIN: observatory ',a,' not found in ./min.local')
        topocentric = .false.
      else
c
c  read la, lo, ht from stdin
c
        topocentric = .true.
        obsname = observatory(3:min(length(observatory),3+len(obsname)))
        i = split(locstr,' ',s,maxstr)
        if (i.lt.3) goto 35
        lambda = reads(s(1))
        phi = reads(s(2))
        read(s(3),*,err=35,end=35) height
        goto 40

35      continue
        write(*,36)
36      format('EQ2AZ: error reading longitude, latitude and height')
        topocentric = .false.
      endif

40    continue

c-----------------------------------------------------------------------

c
c  read edb file and calculate az, ht
c
      open(unit=iu,file=edbfile,status='old',form='formatted')
      write(*,50) datestr(1:length(datestr)),jdate,
     :  obsname(1:length(obsname)),
     :  lambda/degrad,phi/degrad,height
50    format('# ',a,'=',f12.4,'; ',a,',',f8.5,',',f8.5,',',f6.1)

      call lst(jdate,lambda/degrad,s0,ss,st)

100   continue
        read(iu,10,end=110,err=110) line
        if ((length(line).gt.1).and.(index(line(1:1),'#').eq.0)) then
          j = split(line,',',s,maxstr)
          ra = reads(s(3))/12.0d0*180.d0
          de = reads(s(4))
          call eq2az(st,phi,ra,de,a,h)
          write(*,60) s(1)(1:length(s(1))),s(2)(1:length(s(2))),
     :      a/degrad,h/degrad,
     :      s(5)(1:length(s(5))),s(6)(1:length(s(6)))
60        format(a,',',a,',',f9.5,',',f9.5,',',a,',',a)
        endif
      goto 100
110   continue

      close(iu)

      stop

999   continue
      write(*,990)
990   format('EQ2AZ: error reading standard input')

      end

c-----------------------------------------------------------------------
      subroutine eq2az(s,phi,ra,de,a,h)
      implicit none
      real*8 s,phi,ra,de,a,h

      real*8 t,x1(3),x2(3)
      real*8 pi,degrad
      parameter(pi = 3.1415926535d0, degrad = pi/180.0d0)
      real*8 nula2pi

      t = nula2pi(s*pi/12.d0 - ra)
      x1(1) = cos(t)*cos(de)
      x1(2) = sin(t)*cos(de)
      x1(3) = sin(de)
      call rotat2(x1,x2,pi/2.d0-phi)
      a = nula2pi(atan2(x2(2),x2(1)))
      h = asin(x2(3))

      return
      end

